@@ -12,10 +12,10 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 5706 $";
+static char RcsId[] = "@(#)$Revision: 6157 $";
 #endif
 
-/* $Id: hdp_vg.c 5706 2011-11-01 18:23:02Z bmribler $ */
+/* $Id: hdp_vg.c 6157 2014-12-08 05:25:17Z bmribler $ */
 
 #include "hdp.h"
 #ifndef MIPSEL
@@ -649,15 +649,7 @@ void print_fields( char *fields,
           count = 0;
    char  *ptr=NULL, *tempPtr=NULL,
           fldname[MAXNAMELEN],
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__) 
-
-   /* Lets allocate space for tmpflds */
-   *tempflds = (char *)HDmalloc(VSFIELDMAX * FIELDNAMELENMAX * sizeof(char));
-   CHECK_ALLOC( tempflds, "*tempflds", "print_fields" );
-
-#else /* !macintosh */
-   tempflds[VSFIELDMAX*FIELDNAMELENMAX];
-#endif /* !macintosh */
+	  tempflds[VSFIELDMAX*FIELDNAMELENMAX];
 
    /* if fields are not defined by VSsetfields and VSfdefine */
    if( fields[0] == '\0' || fields == NULL )
@@ -697,10 +689,6 @@ void print_fields( char *fields,
       fprintf(fp, "];\n");
    }  /* there are fields to print */
    
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
-    SAFE_FREE(tempflds);	/* free field list and set it to NULL */
-#endif /* macintosh */ 
-
 }  /* end of print_fields */
 
 /* compose the list of indices of the requested vgroups although some
@@ -1059,11 +1047,11 @@ if (num_entries != 0)
 done:
     if (ret_value == FAIL)
       { /* Failure cleanup */
-	aNode = free_node_vg_info_t(aNode);
       }
     /* Normal cleanup */
     SAFE_FREE(vgname);	/* free vg name and set it to NULL */
     SAFE_FREE(vgclass);	/* free vg class name and set it to NULL */
+
     return ret_value;
 }	/* vgBuildGraph */
 
@@ -1093,29 +1081,21 @@ intn vgdumpfull(int32        vg_id,
     char  *name = NULL;
     char  *file_name = dumpvg_opts->ifile_name;
     intn   status, ret_value = SUCCEED;
-
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
-	/* macintosh cannot handle >32K locals */
-   char *fields = (char *)HDmalloc(VSFIELDMAX*FIELDNAMELENMAX* sizeof(char));
-   CHECK_ALLOC( fields, "*fields", "vgdumpfull" );
-
-#else /* !macintosh */
     char   fields[VSFIELDMAX*FIELDNAMELENMAX];
-#endif /* !macintosh */    
 
    aNode->n_entries = num_entries;
 if (num_entries != 0)
 {
-   /* allocate and init memory for storing children's and type's info */
-   aNode->children = alloc_list_of_strings( num_entries );
-   aNode->type = alloc_list_of_strings( num_entries );
-
    /* get the current vgroup's ref# for error message */
    vg_ref = VQueryref( vg_id );
    if( vg_ref == FAIL )
       ERROR_GOTO_2( "in %s: VQueryref failed for vgroup with id=%d",
 		"vgdumpfull", (int) vg_id );
 
+   /* allocate and init memory for storing children's and type's info */
+   aNode->children = alloc_list_of_strings( num_entries );
+   aNode->type = alloc_list_of_strings( num_entries );
+
    for (entry_num = 0; entry_num < num_entries; entry_num++)
    {
       status = Vgettagref(vg_id, entry_num, &elem_tag, &elem_ref);
@@ -1175,13 +1155,13 @@ if (num_entries != 0)
          /* dump attributes for vgroup */
          status = dumpattr(vgt, 0, 0, dumpvg_opts->file_format, fp);
          if( FAIL == status )
-            ERROR_CONT_3( "in %s: %s failed to dump attributes for vgroup with ref#=%d",
+            ERROR_NOTIFY_3( "in %s: %s failed to dump attributes for vgroup with ref#=%d",
 		"vgdumpfull", "dumpattr", (int) elem_ref );
 
          /* dump all of the annotations for this vgroup */
          status = print_data_annots( file_id, file_name, elem_tag, elem_ref );
          if( FAIL == status )
-            ERROR_CONT_3( "in %s: %s failed to dump annotations for vgroup with ref#=%d",
+            ERROR_NOTIFY_3( "in %s: %s failed to dump annotations for vgroup with ref#=%d",
 		"vgdumpfull", "print_data_annots", (int) elem_ref );
 
          resetVG( &vgt, file_name );
@@ -1192,18 +1172,18 @@ if (num_entries != 0)
 
          vs = VSattach(file_id, elem_ref, "r");
          if (vs == FAIL)
-            ERROR_CONT_2( "in %s: VSattach failed for vdata with ref#=%d", 
+            ERROR_NOTIFY_2( "in %s: VSattach failed for vdata with ref#=%d", 
                                  "vgdumpfull", (int) elem_ref );
 
          /* get and print vdata's information */
          status = VSinquire(vs, &nv, &interlace, fields, &vsize, vsname);
          if( FAIL == status )
-            ERROR_CONT_2( "in %s: VSinquire failed for vdata with ref#=%d", 
+            ERROR_NOTIFY_2( "in %s: VSinquire failed for vdata with ref#=%d", 
                                  "vgdumpfull", (int) elem_ref );
    
          vsize = VShdfsize(vs, fields);
          if (vsize == FAIL)
-            ERROR_CONT_2( "in %s: VShdfsize failed for vdata with ref#=%d", 
+            ERROR_NOTIFY_2( "in %s: VShdfsize failed for vdata with ref#=%d", 
                                  "vgdumpfull", (int) elem_ref );
 
 	 /* vdata has no name */
@@ -1211,7 +1191,7 @@ if (num_entries != 0)
                HDstrcat(vsname, "<Undefined>");
    
          if (FAIL == VSgetclass(vs, vsclass))
-               ERROR_CONT_2( "in %s: VSgetclass failed for vdata with ref#=%d", 
+               ERROR_NOTIFY_2( "in %s: VSgetclass failed for vdata with ref#=%d", 
                                  "vgdumpfull", (int) elem_ref );
 
          /* vdata has no class */
@@ -1238,7 +1218,7 @@ if (num_entries != 0)
 				VSnattrs(vs));
 
          if (FAIL == VSdetach(vs))
-               ERROR_CONT_2( "in %s: VSdetach failed for vdata with ref#=%d", 
+               ERROR_NOTIFY_2( "in %s: VSdetach failed for vdata with ref#=%d", 
                                  "vgdumpfull", (int) elem_ref );
 
          /* vdata has no name */
@@ -1277,12 +1257,8 @@ if (num_entries != 0)
 done:
     if (ret_value == FAIL)
       { /* Failure cleanup */
-	  aNode = free_node_vg_info_t(aNode);
       }
     /* Normal cleanup */
-#if defined (MAC) || defined (macintosh) || defined (SYMANTEC_C) || defined(__APPLE__)
-    SAFE_FREE(fields);	/* free field list and set it to NULL */
-#endif /* macintosh */ 
     SAFE_FREE(vgname);	/* free vg name and set it to NULL */
     SAFE_FREE(vgclass);	/* free vg class name and set it to NULL */
 
@@ -1522,6 +1498,9 @@ intn dvg(dump_info_t *dumpvg_opts,
                                   fp, list[curr_vg], &skipfile );
             if( FAIL == status )
             {
+	  /*       HDfree(list[curr_vg]);
+	       list[curr_vg] = NULL;
+ */ 
                ERROR_NOTIFY_3( "in dvg: %s failed for vgroup with ref#=%d in file %s", 
 			      "vgdumpfull", (int) vg_ref, file_name);
 
